@@ -93,7 +93,9 @@ class AuthnDjango(Authn):
 
     def find_realm(self):
         from django.contrib.sites.models import Site
-        return Site.objects.get_current().name
+        if Site._meta.installed:
+            return Site.objects.get_current().name
+        return ''
 
     def is_valid(self, authned):
         return authned.user.is_active
@@ -115,7 +117,7 @@ class AuthnDjangoAPIToken(AuthnDjango):
 
     def __init__(self, model, **kwargs):
         super(AuthnDjangoAPIToken, self).__init__(**kwargs)
-        self.model = model
+        self._model = model
 
     def authenticate(self, request):
         try:
@@ -141,6 +143,13 @@ class AuthnDjangoAPIToken(AuthnDjango):
     def is_valid(self, authned):
         return authned.is_valid()
 
+    @property
+    def model(self):
+        from django.db.models import get_model
+        if isinstance(self._model, str):
+            self._model = get_model(*self._model.split('.', 1))
+        return self._model
+
 class AuthnDjangoBasic(AuthnDjango):
     '''
     Basic authentication using Django's Auth framework.
